==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Long;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosFluentImpl<A extends PodHttpChaosFluent<A>> extends BaseFluent<A> implements PodHttpChaosFluent<A>{
  public PodHttpChaosFluentImpl() {
  }
  public PodHttpChaosFluentImpl(PodHttpChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodHttpChaosSpecBuilder spec;
  private PodHttpChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodHttpChaosFluent.MetadataNested<A> withNewMetadata() {
    return new PodHttpChaosFluentImpl.MetadataNestedImpl();
  }
  public PodHttpChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodHttpChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PodHttpChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodHttpChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodHttpChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodHttpChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodHttpChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodHttpChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodHttpChaosFluent.SpecNested<A> withNewSpec() {
    return new PodHttpChaosFluentImpl.SpecNestedImpl();
  }
  public PodHttpChaosFluent.SpecNested<A> withNewSpecLike(PodHttpChaosSpec item) {
    return new PodHttpChaosFluentImpl.SpecNestedImpl(item);
  }
  public PodHttpChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodHttpChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodHttpChaosSpecBuilder().build());
  }
  public PodHttpChaosFluent.SpecNested<A> editOrNewSpecLike(PodHttpChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodHttpChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodHttpChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodHttpChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(String failedMessage,Long observedGeneration,Long pid,Long startTime) {
    return (A)withStatus(new PodHttpChaosStatus(failedMessage, observedGeneration, pid, startTime));
  }
  public PodHttpChaosFluent.StatusNested<A> withNewStatus() {
    return new PodHttpChaosFluentImpl.StatusNestedImpl();
  }
  public PodHttpChaosFluent.StatusNested<A> withNewStatusLike(PodHttpChaosStatus item) {
    return new PodHttpChaosFluentImpl.StatusNestedImpl(item);
  }
  public PodHttpChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodHttpChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodHttpChaosStatusBuilder().build());
  }
  public PodHttpChaosFluent.StatusNested<A> editOrNewStatusLike(PodHttpChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosFluentImpl that = (PodHttpChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodHttpChaosFluent.MetadataNested<N>> implements PodHttpChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodHttpChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodHttpChaosSpecFluentImpl<PodHttpChaosFluent.SpecNested<N>> implements PodHttpChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodHttpChaosSpec item) {
      this.builder = new PodHttpChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodHttpChaosSpecBuilder(this);
    }
    PodHttpChaosSpecBuilder builder;
    public N and() {
      return (N) PodHttpChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodHttpChaosStatusFluentImpl<PodHttpChaosFluent.StatusNested<N>> implements PodHttpChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodHttpChaosStatus item) {
      this.builder = new PodHttpChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodHttpChaosStatusBuilder(this);
    }
    PodHttpChaosStatusBuilder builder;
    public N and() {
      return (N) PodHttpChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Long;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosFluentImpl<A extends PodHttpChaosFluent<A>> extends BaseFluent<A> implements PodHttpChaosFluent<A>{
  public PodHttpChaosFluentImpl() {
  }
  public PodHttpChaosFluentImpl(PodHttpChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodHttpChaosSpecBuilder spec;
  private PodHttpChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodHttpChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new PodHttpChaosFluentImpl.MetadataNestedImpl();
  }
  public PodHttpChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodHttpChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PodHttpChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodHttpChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodHttpChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodHttpChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodHttpChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodHttpChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodHttpChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new PodHttpChaosFluentImpl.SpecNestedImpl();
  }
  public PodHttpChaosFluentImpl.SpecNested<A> withNewSpecLike(PodHttpChaosSpec item) {
    return new PodHttpChaosFluentImpl.SpecNestedImpl(item);
  }
  public PodHttpChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodHttpChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodHttpChaosSpecBuilder().build());
  }
  public PodHttpChaosFluentImpl.SpecNested<A> editOrNewSpecLike(PodHttpChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodHttpChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodHttpChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodHttpChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(String failedMessage,Long observedGeneration,Long pid,Long startTime) {
    return (A)withStatus(new PodHttpChaosStatus(failedMessage, observedGeneration, pid, startTime));
  }
  public PodHttpChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new PodHttpChaosFluentImpl.StatusNestedImpl();
  }
  public PodHttpChaosFluentImpl.StatusNested<A> withNewStatusLike(PodHttpChaosStatus item) {
    return new PodHttpChaosFluentImpl.StatusNestedImpl(item);
  }
  public PodHttpChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodHttpChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodHttpChaosStatusBuilder().build());
  }
  public PodHttpChaosFluentImpl.StatusNested<A> editOrNewStatusLike(PodHttpChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosFluentImpl that = (PodHttpChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodHttpChaosFluentImpl.MetadataNested<N>> implements PodHttpChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodHttpChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodHttpChaosSpecFluentImpl<PodHttpChaosFluentImpl.SpecNested<N>> implements PodHttpChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodHttpChaosSpec item) {
      this.builder = new PodHttpChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodHttpChaosSpecBuilder(this);
    }
    PodHttpChaosSpecBuilder builder;
    public N and() {
      return (N) PodHttpChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodHttpChaosStatusFluentImpl<PodHttpChaosFluentImpl.StatusNested<N>> implements PodHttpChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodHttpChaosStatus item) {
      this.builder = new PodHttpChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodHttpChaosStatusBuilder(this);
    }
    PodHttpChaosStatusBuilder builder;
    public N and() {
      return (N) PodHttpChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
